@@ -24,7 +24,7 @@ use Padre::Wx::Menu ();
 use Padre::Locale   ();
 use Padre::Current qw{_CURRENT};
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 #####################################################################
 # Methods
@@ -46,7 +46,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'refactor.rename_variable',
 		need_editor => 1,
-		label       => Wx::gettext('Lexically Rename Variable'),
+		label       => Wx::gettext('Rename Variable...'),
 		comment => Wx::gettext('Prompt for a replacement variable name and replace all occurrences of this variable'),
 		menu_event => sub {
 			my $doc = $_[0]->current->document or return;
@@ -54,8 +54,8 @@ sub new {
 			require Padre::Wx::History::TextEntryDialog;
 			my $dialog = Padre::Wx::History::TextEntryDialog->new(
 				$_[0],
-				Wx::gettext("Replacement"),
-				Wx::gettext("Replacement"),
+				Wx::gettext('New name'),
+				Wx::gettext('Rename variable'),
 				'$foo',
 			);
 			return if $dialog->ShowModal == Wx::wxID_CANCEL;
@@ -69,7 +69,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'refactor.extract_subroutine',
 		need_editor => 1,
-		label       => Wx::gettext('Extract Subroutine'),
+		label       => Wx::gettext('Extract Subroutine...'),
 		comment     => Wx::gettext(
 			      'Cut the current selection and create a new sub from it. '
 				. 'A call to this sub is added in the place where the selection was.'
@@ -83,8 +83,8 @@ sub new {
 			require Padre::Wx::History::TextEntryDialog;
 			my $dialog = Padre::Wx::History::TextEntryDialog->new(
 				$_[0],
-				Wx::gettext("Please enter a name for the new subroutine"),
-				Wx::gettext("New Subroutine Name"),
+				Wx::gettext('Name for the new subroutine'),
+				Wx::gettext('Extract Subroutine'),
 				'$foo',
 			);
 			return if $dialog->ShowModal == Wx::wxID_CANCEL;
@@ -99,7 +99,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'refactor.introduce_temporary',
 		need_editor => 1,
-		label       => Wx::gettext('Introduce Temporary Variable'),
+		label       => Wx::gettext('Introduce Temporary Variable...'),
 		comment     => Wx::gettext('Assign the selected expression to a newly declared variable'),
 		menu_event  => sub {
 			my $doc = $_[0]->current->document or return;
@@ -107,8 +107,8 @@ sub new {
 			require Padre::Wx::History::TextEntryDialog;
 			my $dialog = Padre::Wx::History::TextEntryDialog->new(
 				$_[0],
-				Wx::gettext("Variable Name"),
-				Wx::gettext("Variable Name"),
+				Wx::gettext('Variable Name'),
+				Wx::gettext('Introduce Temporary Variable'),
 				'$tmp',
 			);
 			return if $dialog->ShowModal == Wx::wxID_CANCEL;
