@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 =head1 NAME
 
@@ -59,18 +59,26 @@ sub error {
 }
 
 sub _report {
-	my $self    = shift;
-	my $text    = shift;
-	my @samples = @_;
+	my $self     = shift;
+	my $text     = shift;
+	my $prematch = shift;
+	my @samples  = @_;
 
-	my $document = $self->{document};
-	my $editor   = $document->{editor};
+	# The internal _text field is used instead of the document to make sure the
+	# tests can also use it. We will also need to separate from the Padre document class
+	# so this code can be factored out to a stand alone module
 
-	my $prematch = $1 || '';
+	#my $document = $self->{document};
+	#my $editor   = $document->{editor};
+
+	$prematch ||= '';
 	my $error_start_position = length($prematch);
 
-	my $line = $editor->LineFromPosition($error_start_position);
-	++$line; # Editor starts counting at 0
+	#my $line = $editor->LineFromPosition($error_start_position);
+	my @lines = split /[\r\n]/, substr( $self->{_text}, 0, $error_start_position ), -1;
+	my $line = @lines || 1;
+
+	#++$line; # Editor starts counting at 0
 
 	# These are two lines to enable the translators to use argument numbers:
 	$self->{error} = Wx::gettext( sprintf( 'Line %d: ', $line ) ) . Wx::gettext( sprintf( $text, @_ ) );
@@ -83,6 +91,8 @@ sub check {
 
 	$self->{error} = undef;
 
+	$self->{_text} = $text;
+
 	# Fast exits if there is nothing to check:
 	return 1 if !defined($text);
 	return 1 if $text eq '';
@@ -105,9 +115,10 @@ Here @data is in scalar context returning the number of elements. Spotted in thi
 =cut
 
 	if ( $config->begerror_split and $text =~ m/^([\x00-\xff]*?)split([^;]+);/ ) {
-		my $cont = $2;
+		my $prematch = $1;
+		my $cont     = $2;
 		if ( $cont =~ m{\@} ) {
-			$self->_report("The second parameter of split is a string, not an array");
+			$self->_report( "The second parameter of split is a string, not an array", $prematch );
 			return;
 		}
 	}
@@ -121,7 +132,7 @@ s is missing at the end.
 =cut
 
 	if ( $config->begerror_warning and $text =~ /^([\x00-\xff]*?)use\s+warning\s*;/ ) {
-		$self->_report("You need to write use warnings (with an s at the end) and not use warning.");
+		$self->_report( "You need to write use warnings (with an s at the end) and not use warning.", $1 );
 		return;
 	}
 
@@ -142,7 +153,7 @@ which means: map all C<@items> and them add C<$extra_item> without mapping it.
 =cut
 
 	if ( $config->begerror_map and $text =~ /^([\x00-\xff]*?)map[\s\t\r\n]*\{.+?\}[\s\t\r\n]*\(.+?\)[\s\t\r\n]*\,/ ) {
-		$self->_report("map (),x uses x also as list value for map.");
+		$self->_report( "map (),x uses x also as list value for map.", $1 );
 		return;
 	}
 
@@ -155,7 +166,7 @@ Warn about Perl-standard package names being reused
 =cut
 
 	if ( $config->begerror_DB and $text =~ /^([\x00-\xff]*?)package DB[\;\:]/ ) {
-		$self->_report("This file uses the DB-namespace which is used by the Perl Debugger.");
+		$self->_report( "This file uses the DB-namespace which is used by the Perl Debugger.", $1 );
 		return;
 	}
 
@@ -174,7 +185,7 @@ Warn about Perl-standard package names being reused
 	# (Ticket #675)
 
 	if ( $config->begerror_chomp and $text =~ /^([\x00-\xff]*?)(print|[\=\.\,])[\s\t\r\n]*chomp\b/ ) {
-		$self->_report("chomp doesn't return the chomped value, it modifies the variable given as argument.");
+		$self->_report( "chomp doesn't return the chomped value, it modifies the variable given as argument.", $1 );
 		return;
 	}
 
@@ -195,7 +206,7 @@ to actually change the array via s///.
 	if (    $config->begerror_map2
 		and $text =~ /^([\x00-\xff]*?)map[\s\t\r\n]*\{[\s\t\r\n]*(\$_[\s\t\r\n]*\=\~[\s\t\r\n]*)?s\// )
 	{
-		$self->_report("Substitute (s///) doesn't return the changed value even if map.");
+		$self->_report( "Substitute (s///) doesn't return the changed value even if map.", $1 );
 		return;
 	}
 
@@ -206,7 +217,7 @@ to actually change the array via s///.
 =cut
 
 	if ( $config->begerror_perl6 and $text =~ /^([\x00-\xff]*?)\(\<\@\w+\>\)/ ) {
-		$self->_report("(<\@Foo>) is Perl6 syntax and usually not valid in Perl5.");
+		$self->_report( "(<\@Foo>) is Perl6 syntax and usually not valid in Perl5.", $1 );
 		return;
 	}
 
@@ -217,8 +228,12 @@ to actually change the array via s///.
 
 =cut
 
-	if ( $config->begerror_ifsetvar and $text =~ /^([\x00-\xff]*?)if[\s\t\r\n]*\(?[\$\s\t\r\n\w]+\=[\s\t\r\n\$\w]/ ) {
-		$self->_report("A single = in a if-condition is usually a typo, use == or eq to compare.");
+	# TODO if ( my $x = 23 ) {  should be OK I think, that is when we declare the variable with the if construct
+
+	if (    $config->begerror_ifsetvar
+		and $text =~ m/\A([\x00-\xff]*?  ^[^#]*) if\b  \s*  (  \(\s*  (?<!my)\s*[\$\@\%]\w+  \s*=[^=~]  )/xsm )
+	{
+		$self->_report( "A single = in a if-condition is usually a typo, use == or eq to compare.", $1 );
 		return;
 	}
 
@@ -236,7 +251,7 @@ Pipe | in open() not at the end or the beginning.
 		and ( length($5) > 0 )
 		)
 	{
-		$self->_report("Using a | char in open without a | at the beginning or end is usually a typo.");
+		$self->_report( "Using a | char in open without a | at the beginning or end is usually a typo.", $1 );
 		return;
 	}
 
@@ -249,7 +264,7 @@ Pipe | in open() not at the end or the beginning.
 	if (    $config->begerror_pipe2open
 		and $text =~ /^([\x00-\xff]*?)open[\s\t\r\n]*\(?\$?\w+[\s\t\r\n]*\,(.+?\,)?([\"\'])\|.+?\|\3/ )
 	{
-		$self->_report("You can't use open to pipe to and from a command at the same time.");
+		$self->_report( "You can't use open to pipe to and from a command at the same time.", $1 );
 		return;
 	}
 
@@ -263,8 +278,8 @@ Regular expression starting with a quantifier such as
 
 	if ( $config->begerror_regexq and $text =~ m/^([\x00-\xff]*?)\=\~  [\s\t\r\n]*  \/ \^?  [\+\*\?\{] /xs ) {
 		$self->_report(
-			"A regular expression starting with a quantifier ( + * ? { ) doesn't make sense, you may want to escape it with a \\."
-		);
+			"A regular expression starting with a quantifier ( + * ? { ) doesn't make sense, you may want to escape it with a \\.",
+			$1 );
 		return;
 	}
 
@@ -274,8 +289,8 @@ Regular expression starting with a quantifier such as
 
 =cut
 
-	if ( $config->begerror_elseif and $text =~ /^([\x00-\xff]*?)else[\s\t\r\n]+if/ ) {
-		$self->_report("'else if' is wrong syntax, correct if 'elsif'.");
+	if ( $config->begerror_elseif and $text =~ /^([\x00-\xff]*?)\belse\s+if\b/ ) {
+		$self->_report( "'else if' is wrong syntax, correct if 'elsif'.", $1 );
 		return;
 	}
 
@@ -285,8 +300,8 @@ Regular expression starting with a quantifier such as
 
 =cut
 
-	if ( $config->begerror_elseif and $text =~ /^([\x00-\xff]*?)elseif/ ) {
-		$self->_report("'elseif' is wrong syntax, correct if 'elsif'.");
+	if ( $config->begerror_elseif and $text =~ /^([\x00-\xff]*?)\belseif\b/ ) {
+		$self->_report( "'elseif' is wrong syntax, correct if 'elsif'.", $1 );
 		return;
 	}
 
@@ -297,7 +312,7 @@ Regular expression starting with a quantifier such as
 =cut
 
 	if ( $config->begerror_close and $text =~ /^(.*?[^>]?)close;/ ) { # don't match Socket->close;
-		$self->_report("close; usually closes STDIN, STDOUT or something else you don't want.");
+		$self->_report( "close; usually closes STDIN, STDOUT or something else you don't want.", $1 );
 		return;
 	}
 
@@ -338,18 +353,15 @@ Go to F<Config.pm>, look for the beginner error checks configuration and add a n
 setting for your new check there. It defaults to 1 (run the check), but a user
 could turn it off by setting this to 0 within the Padre configuration file.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2010 The Padre development team as listed in Padre.pm.
 
-=head1 LICENSE
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
-
-=head1 WARRANTY
-
-There is no warranty whatsoever.
+The full text of the license can be found in the
+LICENSE file included with this module.
 
 =cut
 
