@@ -3,11 +3,12 @@ package Padre::Task::HTTPClient;
 use 5.008;
 use strict;
 use warnings;
-use Padre::Constant ();
+
+use Padre::Util::SVN ();
 
 # Use all modules which may provide services for us:
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 our @DRIVERS = qw{
 	Padre::Task::HTTPClient::LWP
 };
@@ -49,8 +50,7 @@ sub new {
 	}
 
 	# Prepare information
-	require Padre::Util::SVN;
-	my $revision = Padre::Util::SVN::padre_version();
+	my $revision = Padre::Util::SVN->padre_revision() || 'na';
 	$args{method} ||= 'GET';
 	$args{headers}->{'X-Padre'} ||= "Padre version $VERSION $revision";
 
