@@ -10,17 +10,31 @@ use File::Spec        ();
 use Padre::Wx         ();
 use Padre::Wx::Dialog ();
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
+
+our %license_id = ( # TODO: check for other module builders as well
+	Wx::gettext('Apache License')         => 'apache',       ## TODO: does not work w/ Module::Build
+	Wx::gettext('Artistic License 1.0')   => 'artistic',     ## TODO: does not work w/ Module::Build
+	Wx::gettext('Artistic License 2.0')   => 'artistic_2',   ## TODO: does not work w/ Module::Build
+	Wx::gettext('Revised BSD License')    => 'bsd',
+	Wx::gettext('GPL 2 or later')         => 'gpl',
+	Wx::gettext('LGPL 2.1 or later')      => 'lgpl',
+	Wx::gettext('MIT License')            => 'mit',
+	Wx::gettext('Mozilla Public License') => 'mozilla',      ## TODO: does not work w/ Module::Build
+	Wx::gettext('Open Source')            => 'open_source',  ## TODO: does not work w/ Module::Build
+	Wx::gettext('Perl licensing terms')   => 'perl',
+	Wx::gettext('restrictive')            => 'restrictive',  ## TODO: does not work w/ Module::Build
+	Wx::gettext('unrestricted')           => 'unrestricted', ## TODO: does not work w/ Module::Build
+);
+
+# licenses list taken from
+# http://search.cpan.org/dist/Module-Build/lib/Module/Build/API.pod
+# even though it should be in http://module-build.sourceforge.net/META-spec.html
+# and we should fetch it from Module::Start or maybe Software::License
+
 
 sub get_layout {
-
-	my @builders = ( 'Module::Build', 'ExtUtils::MakeMaker', 'Module::Install' );
-	my @licenses = qw(apache artistic artistic_2 bsd gpl lgpl mit mozilla open_source perl restrictive unrestricted);
-
-	# licenses list taken from
-	# http://search.cpan.org/dist/Module-Build/lib/Module/Build/API.pod
-	# even though it should be in http://module-build.sourceforge.net/META-spec.html
-	# and we should fetch it from Module::Start or maybe Software::License
+	my @builders = ( 'Module::Build', 'ExtUtils::MakeMaker', 'Module::Install' ); # TODO: what about Module::Starter?
 
 	my @layout = (
 		[   [ 'Wx::StaticText', undef,           Wx::gettext('Module Name:') ],
@@ -29,14 +43,16 @@ sub get_layout {
 		[   [ 'Wx::StaticText', undef,           Wx::gettext('Author:') ],
 			[ 'Wx::TextCtrl',   '_author_name_', '' ],
 		],
-		[   [ 'Wx::StaticText', undef,     Wx::gettext('Email:') ],
+		[   [ 'Wx::StaticText', undef,     Wx::gettext('Email Address:') ],
 			[ 'Wx::TextCtrl',   '_email_', '' ],
 		],
 		[   [ 'Wx::StaticText', undef, Wx::gettext('Builder:') ],
-			[ 'Wx::ComboBox', '_builder_choice_', '', \@builders ],
+			[ 'Wx::ComboBox', '_builder_choice_', '', \@builders, Wx::wxCB_READONLY ],
 		],
-		[   [ 'Wx::StaticText', undef, Wx::gettext('License:') ],
-			[ 'Wx::ComboBox', '_license_choice_', '', \@licenses ],
+		[   [ 'Wx::StaticText', undef,              Wx::gettext('License:') ],
+			[ 'Wx::ComboBox',   '_license_choice_', '', [ keys %license_id ], Wx::wxCB_SORT ],
+
+			# TODO: SORT does not seem to work on Linux
 		],
 		[   [ 'Wx::StaticText', undef, Wx::gettext('Parent Directory:') ],
 			[ 'Wx::DirPickerCtrl', '_directory_', '', Wx::gettext('Pick parent directory') ],
@@ -65,10 +81,10 @@ sub dialog {
 	my $layout = get_layout();
 	my $dialog = Padre::Wx::Dialog->new(
 		parent => $parent,
-		title  => Wx::gettext("Module Start"),
+		title  => Wx::gettext('Module Start'),
 		layout => $layout,
-		width  => [ 100, 200 ],
-		bottom => 20,
+		width  => [ 200, 300 ],
+		bottom => 10,
 	);
 
 	$dialog->{_widgets_}->{_author_name_}->SetValue( $config->identity_name );
@@ -81,7 +97,7 @@ sub dialog {
 	if ( $config->license ) {
 		$dialog->{_widgets_}->{_license_choice_}->SetValue( $config->license );
 	} else {
-		$dialog->{_widgets_}->{_license_choice_}->SetValue('restrictive');
+		$dialog->{_widgets_}->{_license_choice_}->SetValue( Wx::gettext('Perl licensing terms') );
 	}
 	$dialog->{_widgets_}->{_directory_}->SetPath( $config->module_start_directory );
 
@@ -110,13 +126,13 @@ sub ok_clicked {
 
 	my $main = Padre->ide->wx->main;
 
-	# TO DO improve input validation !
+	# TODO improve input validation !
 	my @fields = qw(_module_name_ _author_name_ _email_ _builder_choice_ _license_choice_);
 	foreach my $f (@fields) {
 		if ( not $data->{$f} ) {
 			Wx::MessageBox(
-				sprintf( Wx::gettext("Field %s was missing. Module not created."), $f ),
-				Wx::gettext("missing field"), Wx::wxOK, $main
+				sprintf( Wx::gettext('Field %s was missing. Module not created.'), $f ),
+				Wx::gettext('missing field'), Wx::wxOK, $main
 			);
 			return;
 		}
@@ -130,7 +146,8 @@ sub ok_clicked {
 	$config->set( 'module_start_directory', $data->{_directory_} );
 
 	my $pwd = Cwd::cwd();
-	chdir $data->{_directory_};
+	my $parent_dir = $data->{_directory_} eq '' ? './' : $data->{_directory_};
+	chdir $parent_dir;
 	eval {
 		require Module::Starter::App;
 		local @ARGV = (
@@ -138,7 +155,9 @@ sub ok_clicked {
 			'--author',  $data->{_author_name_},
 			'--email',   $data->{_email_},
 			'--builder', $data->{_builder_choice_},
-			'--license', $data->{_license_choice_},
+			'--license', exists $license_id{ $data->{_license_choice_} }
+			? $license_id{ $data->{_license_choice_} }
+			: $data->{_license_choice_},
 		);
 		Module::Starter::App->run;
 	};
@@ -150,34 +169,26 @@ sub ok_clicked {
 				Wx::gettext("An error has occured while generating '%s':\n%s"),
 				$data->{_module_name_}, $@
 			),
-			Wx::gettext("Error"),
+			Wx::gettext('Error'),
 			Wx::wxOK | Wx::wxCENTRE,
 			$main
 		);
 		return;
 	}
 
-	my $ret = Wx::MessageBox(
-		sprintf( Wx::gettext("%s apparently created. Do you want to open it now?"), $data->{_module_name_} ),
-		Wx::gettext("Done"),
-		Wx::wxYES_NO | Wx::wxCENTRE,
-		$main,
+	my $module_name = $data->{_module_name_};
+	($module_name) = split( ',', $module_name ); # for Foo::Bar,Foo::Bat
+	                                             # prepare Foo-Bar/lib/Foo/Bar.pm
+	my @parts = split( '::', $module_name );
+	my $dir_name = join( '-', @parts );
+	$parts[-1] .= '.pm';
+	my $file = File::Spec->catfile( $parent_dir, $dir_name, 'lib', @parts );
+	Padre::DB::History->create(
+		type => 'files',
+		name => $file,
 	);
-	if ( $ret == Wx::wxYES ) {
-		my $module_name = $data->{_module_name_};
-		($module_name) = split( ',', $module_name ); # for Foo::Bar,Foo::Bat
-		                                             # prepare Foo-Bar/lib/Foo/Bar.pm
-		my @parts = split( '::', $module_name );
-		my $dir_name = join( '-', @parts );
-		$parts[-1] .= '.pm';
-		my $file = File::Spec->catfile( $data->{_directory_}, $dir_name, 'lib', @parts );
-		Padre::DB::History->create(
-			type => 'files',
-			name => $file,
-		);
-		$main->setup_editor($file);
-		$main->refresh;
-	}
+	$main->setup_editor($file);
+	$main->refresh;
 
 	return;
 }
