@@ -12,7 +12,7 @@ use Padre::Wx       ();
 use Padre::Wx::Menu ();
 use Padre::Locale   ();
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 our @ISA     = 'Padre::Wx::Menu';
 
 my @GUI_ELEMENTS = (
@@ -84,7 +84,7 @@ sub new {
 	foreach my $name ( sort { lc($a) cmp lc($b) } keys %mimes ) {
 		my $label = $name;
 		$label =~ s/^\d+//;
-		my $tag = "view.view_as" . lc $label;
+		my $tag = "view.view_as_" . lc $label;
 		$tag =~ s/\s/_/g;
 		$self->add_radio_menu_item(
 			$self->{view_as_highlighting},
@@ -294,11 +294,14 @@ sub new {
 			$label = "English (New Britstralian)";
 		}
 
+		my $langobj = Padre::Locale::object($name);
+		my $utf8txt = ' (' . Padre::Locale::label($name) . ')';
+
 		my $radio = $self->add_radio_menu_item(
 			$self->{language},
 			name       => $tag,
-			label      => $label,
-			comment    => sprintf( Wx::gettext('Switch menus to %s'), $label ),
+			label      => $label . $utf8txt,
+			comment    => sprintf( Wx::gettext('Switch menus to %s'), $label ) . $utf8txt,
 			menu_event => sub {
 				$_[0]->change_locale($name);
 			},
@@ -366,7 +369,7 @@ sub refresh {
 		my $has_checked = 0;
 		if ( $document->mimetype ) {
 			my %mimes = Padre::MimeTypes::menu_view_mimes();
-			my @mimes = sort keys %mimes;
+			my @mimes = sort { lc($a) cmp lc($b) } keys %mimes;
 			foreach my $pos ( 0 .. scalar @mimes - 1 ) {
 				my $radio = $self->{view_as_highlighting}->FindItemByPosition($pos);
 				if ( $document->mimetype eq $mimes{ $mimes[$pos] } ) {
