@@ -10,7 +10,7 @@ use Padre::Wx       ();
 use Padre::Wx::Menu ();
 use Padre::Current  ('_CURRENT');
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 our @ISA     = 'Padre::Wx::Menu';
 
 
@@ -118,6 +118,7 @@ sub refresh_windowlist {
 	my $previous = $self->GetMenuItemCount - $self->{base} - 1;
 	my $pages    = $notebook->GetPageCount - 1;
 	my @label    = $notebook->labels;
+	my @order    = sort { $label[$a] cmp $label[$b] } ( 0 .. $#label );
 
 	# If we are changing from none to any, add the separator
 	if ( $previous == -1 ) {
@@ -128,17 +129,16 @@ sub refresh_windowlist {
 
 	# Overwrite the labels of existing entries where possible
 	foreach my $nth ( 0 .. List::Util::min( $previous, $pages ) ) {
-		$self->FindItemByPosition( $self->{base} + $nth + 1 )->SetText( $label[$nth] );
+		$self->FindItemByPosition( $self->{base} + $nth + 1 )->SetText( $label[ $order[$nth] ] );
 	}
 
 	# Add menu entries if we have extra labels
 	foreach my $nth ( $previous + 1 .. $pages ) {
-		my $item = $self->Append( -1, $label[$nth] );
 		Wx::Event::EVT_MENU(
 			$self->{main},
-			$item,
+			$self->Append( -1, $label[ $order[$nth] ] ),
 			sub {
-				$_[0]->on_nth_pane($nth);
+				$_[0]->on_nth_pane( $order[$nth] );
 			},
 		);
 	}
